==> ejc-probid-api-3.0.0-20220715.092937-10-sources.jar: com/ejianc/business/review/vo/ReviewFundVO.java <==
package com.ejianc.business.review.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 投标文件评审-资金情况实体
 *
 * @author generator
 */
public class ReviewFundVO extends BaseVO {
	private static final long serialVersionUID = -8122509543070768113L;

	private Long sourceBidRecordSubFundId; // 工程投标备案-资金情况id
	private Long sourceBidRecordId; // 工程投标备案id
	private Long sourceCapitalId; // 资金来源id
	private String sourceCapitalCode; // 资金来源编码
	private String sourceCapitalName; // 资金来源名称
	private BigDecimal scale; // 比例
	private Long bidFileReviewId; // 投标文件评审id


	public Long getSourceBidRecordSubFundId() {
		return sourceBidRecordSubFundId;
	}

	public void setSourceBidRecordSubFundId(Long sourceBidRecordSubFundId) {
		this.sourceBidRecordSubFundId = sourceBidRecordSubFundId;
	}

	public Long getSourceBidRecordId() {
		return sourceBidRecordId;
	}

	public void setSourceBidRecordId(Long sourceBidRecordId) {
		this.sourceBidRecordId = sourceBidRecordId;
	}

	public Long getSourceCapitalId() {
		return sourceCapitalId;
	}

	public void setSourceCapitalId(Long sourceCapitalId) {
		this.sourceCapitalId = sourceCapitalId;
	}

	public String getSourceCapitalCode() {
		return sourceCapitalCode;
	}

	public void setSourceCapitalCode(String sourceCapitalCode) {
		this.sourceCapitalCode = sourceCapitalCode;
	}

	public String getSourceCapitalName() {
		return sourceCapitalName;
	}

	public void setSourceCapitalName(String sourceCapitalName) {
		this.sourceCapitalName = sourceCapitalName;
	}

	public BigDecimal getScale() {
		return scale;
	}

	public void setScale(BigDecimal scale) {
		this.scale = scale;
	}

	public Long getBidFileReviewId() {
		return bidFileReviewId;
	}

	public void setBidFileReviewId(Long bidFileReviewId) {
		this.bidFileReviewId = bidFileReviewId;
	}

}

==> ejc-probid-api-3.0.0-20250924.090452-93-sources.jar: com/ejianc/business/review/vo/ReviewFundVO.java <==
package com.ejianc.business.review.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 投标文件评审-资金情况实体
 *
 * @author generator
 */
public class ReviewFundVO extends BaseVO {
	private static final long serialVersionUID = -9166135538037137243L;

	private Long sourceBidRecordSubFundId; // 工程投标备案-资金情况id
	private Long sourceBidRecordPid; // 工程投标备案id
	private Long sourceCapitalId; // 资金来源id
	private String sourceCapitalCode; // 资金来源编码
	private String sourceCapitalName; // 资金来源名称
	private BigDecimal scale; // 比例
	private Long bidFileReviewId; // 投标文件评审id


	public Long getSourceBidRecordSubFundId() {
		return sourceBidRecordSubFundId;
	}

	public void setSourceBidRecordSubFundId(Long sourceBidRecordSubFundId) {
		this.sourceBidRecordSubFundId = sourceBidRecordSubFundId;
	}

	public Long getSourceBidRecordPid() {
		return sourceBidRecordPid;
	}

	public void setSourceBidRecordPid(Long sourceBidRecordPid) {
		this.sourceBidRecordPid = sourceBidRecordPid;
	}

	public Long getSourceCapitalId() {
		return sourceCapitalId;
	}

	@ReferDeserialTransfer
	public void setSourceCapitalId(Long sourceCapitalId) {
		this.sourceCapitalId = sourceCapitalId;
	}

	public String getSourceCapitalCode() {
		return sourceCapitalCode;
	}

	public void setSourceCapitalCode(String sourceCapitalCode) {
		this.sourceCapitalCode = sourceCapitalCode;
	}

	public String getSourceCapitalName() {
		return sourceCapitalName;
	}

	public void setSourceCapitalName(String sourceCapitalName) {
		this.sourceCapitalName = sourceCapitalName;
	}

	public BigDecimal getScale() {
		return scale;
	}

	public void setScale(BigDecimal scale) {
		this.scale = scale;
	}

	public Long getBidFileReviewId() {
		return bidFileReviewId;
	}

	public void setBidFileReviewId(Long bidFileReviewId) {
		this.bidFileReviewId = bidFileReviewId;
	}

}
